@@ -156,6 +156,12 @@ audio.add_command(list_genres)
 
 
 @click.command()
+@click.option(
+    "--language",
+    multiple=False,
+    help="Which language the moods will be returned in",
+    type=str,
+)
 def list_instruments(**kwargs):
     """
     List audio instruments
@@ -168,6 +174,12 @@ audio.add_command(list_instruments)
 
 
 @click.command()
+@click.option(
+    "--language",
+    multiple=False,
+    help="Which language the moods will be returned in",
+    type=str,
+)
 def list_moods(**kwargs):
     """
     List audio moods
@@ -289,6 +301,12 @@ audio.add_command(license_track)
     help="Filter licenses by download availability",
     type=str,
 )
+@click.option(
+    "--team-history",
+    multiple=False,
+    help="Set to true to see license history for all members of your team.",
+    type=str,
+)
 def get_track_license_list(**kwargs):
     """
     List audio licenses
