@@ -44,6 +44,15 @@ catalog.add_command(search_catalog)
 @click.option("--page", multiple=False, help="Page number", type=int)
 @click.option("--per-page", multiple=False, help="Number of results per page", type=int)
 @click.option("--sort", multiple=False, help="Sort by", type=str)
+@click.option(
+    "--shared",
+    multiple=False,
+    help=(
+        "Set to true to omit collections that you own and return only collections  that"
+        " are shared with you"
+    ),
+    type=str,
+)
 def get_collections(**kwargs):
     """
     List catalog collections
