@@ -6,6 +6,8 @@ import click
 
 from .images import images
 
+from .bulk_search import bulk_search
+
 from .videos import videos
 
 from .audio import audio
@@ -35,6 +37,8 @@ def cli():
 
 cli.add_command(images)
 
+cli.add_command(bulk_search)
+
 cli.add_command(videos)
 
 cli.add_command(audio)
