@@ -300,6 +300,25 @@ def get_image_keyword_suggestions(**kwargs):
 images.add_command(get_image_keyword_suggestions)
 
 
+@click.command()
+@click.option("--id", multiple=True, help="One or more image IDs", type=str)
+@click.option(
+    "--view",
+    multiple=False,
+    help="Amount of detail to render in the response",
+    type=str,
+)
+def get_image_list(**kwargs):
+    """
+    List images
+    """
+
+    get(url="/v2/images", params=kwargs, json_data=None)
+
+
+images.add_command(get_image_list)
+
+
 @click.command()
 @click.argument("id")
 @click.option(
@@ -359,7 +378,7 @@ images.add_command(list_image_categories)
     help="Amount of detail to render in the response",
     type=str,
 )
-def get_similar_images(**kwargs):
+def list_similar_images(**kwargs):
     """
     List similar images
     """
@@ -367,7 +386,7 @@ def get_similar_images(**kwargs):
     get(url="/v2/images/" + kwargs["id"] + "/similar", params=kwargs, json_data=None)
 
 
-images.add_command(get_similar_images)
+images.add_command(list_similar_images)
 
 
 @click.command()
@@ -449,6 +468,12 @@ images.add_command(license_images)
     help="Filter licenses by download availability",
     type=str,
 )
+@click.option(
+    "--team-history",
+    multiple=False,
+    help="Set to true to see license history for all members of your team.",
+    type=str,
+)
 def get_image_license_list(**kwargs):
     """
     List image licenses
@@ -818,22 +843,3 @@ def get_updated_images(**kwargs):
 
 
 images.add_command(get_updated_images)
-
-
-@click.command()
-@click.option("--id", multiple=True, help="One or more image IDs", type=str)
-@click.option(
-    "--view",
-    multiple=False,
-    help="Amount of detail to render in the response",
-    type=str,
-)
-def get_image_list(**kwargs):
-    """
-    List images
-    """
-
-    get(url="/v2/images", params=kwargs, json_data=None)
-
-
-images.add_command(get_image_list)
