@@ -23,7 +23,10 @@ class RequestHelper:
         self.custom_url = os.getenv("SHUTTERSTOCK_CUSTOM_URL")
 
         self._auth = None
-        self._headers = {"User-Agent": "Shutterstock-CLI"}
+        self._headers = {
+            "User-Agent": "Shutterstock-CLI",
+            "x-shutterstock-application": "CLI",
+        }
 
         if self.token:
             self._headers.update({"Authorization": f"Bearer {self.token}"})
